@@ -1,6 +1,4 @@
-context("test schema validation")
-
-library(amap)
+# library(amap)
 library(clue)
 library(data.table)
 library(glmnet)
